==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterNodePoolAutoConfig.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:40.266Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterNodePoolAutoConfig")
@software.amazon.jsii.Jsii.Proxy(ContainerClusterNodePoolAutoConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ContainerClusterNodePoolAutoConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * network_tags block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#network_tags ContainerCluster#network_tags}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags getNetworkTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ContainerClusterNodePoolAutoConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ContainerClusterNodePoolAutoConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ContainerClusterNodePoolAutoConfig> {
        com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags networkTags;

        /**
         * Sets the value of {@link ContainerClusterNodePoolAutoConfig#getNetworkTags}
         * @param networkTags network_tags block.
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/container_cluster#network_tags ContainerCluster#network_tags}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder networkTags(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags networkTags) {
            this.networkTags = networkTags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ContainerClusterNodePoolAutoConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ContainerClusterNodePoolAutoConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ContainerClusterNodePoolAutoConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ContainerClusterNodePoolAutoConfig {
        private final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags networkTags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.networkTags = software.amazon.jsii.Kernel.get(this, "networkTags", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.networkTags = builder.networkTags;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags getNetworkTags() {
            return this.networkTags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNetworkTags() != null) {
                data.set("networkTags", om.valueToTree(this.getNetworkTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.containerCluster.ContainerClusterNodePoolAutoConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ContainerClusterNodePoolAutoConfig.Jsii$Proxy that = (ContainerClusterNodePoolAutoConfig.Jsii$Proxy) o;

            return this.networkTags != null ? this.networkTags.equals(that.networkTags) : that.networkTags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.networkTags != null ? this.networkTags.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/container_cluster/ContainerClusterNodePoolAutoConfig.java <==
package com.hashicorp.cdktf.providers.google.container_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:14.209Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.containerCluster.ContainerClusterNodePoolAutoConfig")
@software.amazon.jsii.Jsii.Proxy(ContainerClusterNodePoolAutoConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ContainerClusterNodePoolAutoConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * network_tags block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#network_tags ContainerCluster#network_tags}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags getNetworkTags() {
        return null;
    }

    /**
     * A map of resource manager tags.
     * <p>
     * Resource manager tag keys and values have the same definition as resource manager tags. Keys must be in the format tagKeys/{tag_key_id}, and values are in the format tagValues/456. The field is ignored (both PUT & PATCH) when empty.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#resource_manager_tags ContainerCluster#resource_manager_tags}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getResourceManagerTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ContainerClusterNodePoolAutoConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ContainerClusterNodePoolAutoConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ContainerClusterNodePoolAutoConfig> {
        com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags networkTags;
        java.util.Map<java.lang.String, java.lang.String> resourceManagerTags;

        /**
         * Sets the value of {@link ContainerClusterNodePoolAutoConfig#getNetworkTags}
         * @param networkTags network_tags block.
         *                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#network_tags ContainerCluster#network_tags}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder networkTags(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags networkTags) {
            this.networkTags = networkTags;
            return this;
        }

        /**
         * Sets the value of {@link ContainerClusterNodePoolAutoConfig#getResourceManagerTags}
         * @param resourceManagerTags A map of resource manager tags.
         *                            Resource manager tag keys and values have the same definition as resource manager tags. Keys must be in the format tagKeys/{tag_key_id}, and values are in the format tagValues/456. The field is ignored (both PUT & PATCH) when empty.
         *                            
         *                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/container_cluster#resource_manager_tags ContainerCluster#resource_manager_tags}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceManagerTags(java.util.Map<java.lang.String, java.lang.String> resourceManagerTags) {
            this.resourceManagerTags = resourceManagerTags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ContainerClusterNodePoolAutoConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ContainerClusterNodePoolAutoConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ContainerClusterNodePoolAutoConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ContainerClusterNodePoolAutoConfig {
        private final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags networkTags;
        private final java.util.Map<java.lang.String, java.lang.String> resourceManagerTags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.networkTags = software.amazon.jsii.Kernel.get(this, "networkTags", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags.class));
            this.resourceManagerTags = software.amazon.jsii.Kernel.get(this, "resourceManagerTags", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.networkTags = builder.networkTags;
            this.resourceManagerTags = builder.resourceManagerTags;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.container_cluster.ContainerClusterNodePoolAutoConfigNetworkTags getNetworkTags() {
            return this.networkTags;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getResourceManagerTags() {
            return this.resourceManagerTags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getNetworkTags() != null) {
                data.set("networkTags", om.valueToTree(this.getNetworkTags()));
            }
            if (this.getResourceManagerTags() != null) {
                data.set("resourceManagerTags", om.valueToTree(this.getResourceManagerTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.containerCluster.ContainerClusterNodePoolAutoConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ContainerClusterNodePoolAutoConfig.Jsii$Proxy that = (ContainerClusterNodePoolAutoConfig.Jsii$Proxy) o;

            if (this.networkTags != null ? !this.networkTags.equals(that.networkTags) : that.networkTags != null) return false;
            return this.resourceManagerTags != null ? this.resourceManagerTags.equals(that.resourceManagerTags) : that.resourceManagerTags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.networkTags != null ? this.networkTags.hashCode() : 0;
            result = 31 * result + (this.resourceManagerTags != null ? this.resourceManagerTags.hashCode() : 0);
            return result;
        }
    }
}
